==> ultracopier_0.3.1.0.orig.tar.xz: ultracopier-src/plugins-alternative/Themes/Clean/Languages/it/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it" sourcelanguage="en">
<context>
    <name>InterfacePlugin</name>
    <message>
        <location filename="../../interface.cpp" line="145"/>
        <source>%1/%2 files, %3/%4</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>interface</name>
    <message>
        <location filename="../../interface.ui" line="32"/>
        <source>Action:</source>
        <translation>Azione:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>In wait</source>
        <translation>In attesa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="78"/>
        <source>Add file</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="87"/>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="96"/>
        <source>Move file(s)</source>
        <translation>Spostare file(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="105"/>
        <source>Move folder</source>
        <translation>Spostare la cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="114"/>
        <source>Copy file(s)</source>
        <translation>Copiare il file (s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="123"/>
        <source>Copy folder</source>
        <translation>Copia la cartella</translation>
    </message>
</context>
</TS>

==> ultracopier_1.4.0.6.orig.tar.xz: ultracopier-src/plugins-alternative/Themes/Clean/Languages/it/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>InterfacePlugin</name>
    <message>
        <location filename="../../interface.cpp" line="142"/>
        <source>%1/%2 files, %3/%4</source>
        <translation>%1/%2 file, %3/%4</translation>
    </message>
</context>
<context>
    <name>interface</name>
    <message>
        <location filename="../../interface.ui" line="32"/>
        <source>Action:</source>
        <translation>Azione:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="78"/>
        <source>Add file</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="87"/>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="96"/>
        <source>Move file(s)</source>
        <translation>Sposta file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="105"/>
        <source>Move folder</source>
        <translation>Sposta la cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="114"/>
        <source>Copy file(s)</source>
        <translation>Copia file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="123"/>
        <source>Copy folder</source>
        <translation>Copia cartella</translation>
    </message>
</context>
</TS>
